import { SdkServerSideNetworkAdaption } from '../signalingprotocol/SignalingProtocol';
/**
 * [[ServerSideNetworkAdaption]] represents additional server side features that can be enabled for network adaption.
 */
export declare enum ServerSideNetworkAdaption {
    /**
     * This value will currently be overwritten to `BandwidthProbingAndRemoteVideoQualityAdaption`
     */
    Default = 0,
    /**
     * @deprecated: Please switch to 'BandwidthProbingAndRemoteVideoQualityAdaption'
     */
    None = 1,
    /**
     * @deprecated: Please switch to 'BandwidthProbingAndRemoteVideoQualityAdaption'.
     */
    BandwidthProbing = 2,
    /**
     * Disable internal policy behavior and proxy priorities to server to automatically
     * switch, pause, or resume streams based on server calculated network constraints. This will
     * significantly improve response times when network constraints occur. This will also support the
     * features covered in `BandwidthProbing` though possibly with different implementation details.
     *
     * End users should overall see reduced video freezes, reduced broken audio, and reduced packet loss.
     * The value impacts response to network events and may lead to remote video pauses/downgrades
     * that did not occur before.
     */
    BandwidthProbingAndRemoteVideoQualityAdaption = 3
}
export default ServerSideNetworkAdaption;
export declare function serverSideNetworkAdaptionIsNoneOrDefault(adaption: ServerSideNetworkAdaption): boolean;
export declare function convertServerSideNetworkAdaptionEnumFromSignaled(adaption: SdkServerSideNetworkAdaption): ServerSideNetworkAdaption;
export declare function convertServerSideNetworkAdaptionEnumToSignaled(adaption: ServerSideNetworkAdaption): SdkServerSideNetworkAdaption;
