import ServerSideNetworkAdaption from '../signalingclient/ServerSideNetworkAdaption';
/**
 * [[VideoPriorityBasedPolicyConfig]] contains the network issue response delay and network issue recovery delay.
 */
export default class VideoPriorityBasedPolicyConfig {
    networkIssueResponseDelayFactor: number;
    networkIssueRecoveryDelayFactor: number;
    private static readonly MINIMUM_DELAY_MS;
    private static readonly MAXIMUM_DELAY_MS;
    static readonly Default: VideoPriorityBasedPolicyConfig;
    static readonly UnstableNetworkPreset: VideoPriorityBasedPolicyConfig;
    static readonly StableNetworkPreset: VideoPriorityBasedPolicyConfig;
    private currentNetworkEvent;
    private bandwidthDecreaseTimestamp;
    private referenceBitrate;
    /**
     * Additional server side features to be enabled for network adaption. The only currently
     * recommended value is `ServerSideNetworkAdaption.BandwidthProbingAndRemoteVideoQualityAdaption`
     */
    serverSideNetworkAdaption: ServerSideNetworkAdaption;
    /** Initializes a [[VideoPriorityBasedPolicyConfig]] with the network event delays.
     *
     * @deprecated These values are not used when server side network adaptation is used, which will
     * become the default in the future. Therefore these constructors
     * will be deprecated and removed in a later releases.
     *
     * @param networkIssueResponseDelayFactor Delays before reducing subscribed video bitrate. Input should be a value between 0 and 1.
     * @param networkIssueRecoveryDelayFactor Delays before starting to increase bitrates after a network event and
     * delays between increasing video bitrates on each individual stream. Input should be a value between 0 and 1.
     */
    constructor(networkIssueResponseDelayFactor?: number, networkIssueRecoveryDelayFactor?: number);
    allowSubscribe(numberOfParticipants: number, currentEstimated: number): boolean;
    private getSubscribeDelay;
}
